/*
 * Copyright (C) 2006-2008 the VideoLAN team
 *
 * This file is part of VLMa.
 * 
 * VLMa is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 * 
 * VLMa is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with VLMa. If not, see <http://www.gnu.org/licenses/>.
 *
 */

package org.videolan.vlma.web.welcome;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.Controller;
import org.videolan.vlma.common.IVlData;
import org.videolan.vlma.common.medias.IVlMedia;
import org.videolan.vlma.common.medias.VlTNTChannel;
import org.videolan.vlma.common.medias.VlFilesChannel;
import org.videolan.vlma.common.medias.VlSatChannel;

public class WelcomeFormController implements Controller {

    public ModelAndView handleRequest(HttpServletRequest arg0,
            HttpServletResponse arg1) throws Exception {
        Map<String, Object> params = new HashMap<String, Object>();
        List<VlSatChannel> channelsSat = new ArrayList<VlSatChannel>();
        List<VlTNTChannel> channelsTNT = new ArrayList<VlTNTChannel>();
        List<VlFilesChannel> fileChannels = new ArrayList<VlFilesChannel>();
        for (IVlMedia media : data.getMedias())
            if (media.getProgram() != null)
                if (media.getClass().equals(VlSatChannel.class))
                {
                    VlSatChannel channel = (VlSatChannel) media;
                    channelsSat.add(channel);
                }
                else if (media.getClass().equals(VlTNTChannel.class))
                {
                    VlTNTChannel channel = (VlTNTChannel) media;
                    channelsTNT.add(channel);
                }
                else if (media.getClass().equals(VlFilesChannel.class))
                {
                    VlFilesChannel channel = (VlFilesChannel) media;
                    fileChannels.add(channel);
                }
        params.put("channelsSat", channelsSat);
        params.put("channelsTNT", channelsTNT);
        params.put("fileChannels", fileChannels);
        params.put("servers", data.getServers());
        return new ModelAndView("welcome/welcome", params);
    }

    private IVlData data;

    public IVlData getData() {
        return data;
    }

    public void setData(IVlData data) {
        this.data = data;
    }

}
